@@ -8,7 +8,7 @@ use Carp;
 use vars qw( $SOCKET_CLASS @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $VERSION $SOCKS_ERROR $SOCKS5_RESOLVE $SOCKS4_RESOLVE $SOCKS_DEBUG %CODES );
 require Exporter;
 
-$VERSION = '0.72';
+$VERSION = '0.73';
 
 use constant {
 	SOCKS_WANT_READ  => 20,
@@ -158,7 +158,7 @@ sub new_from_fd {
 	
 	# do not allow to create new socket
 	local $CAN_CHANGE_SOCKET = 0;
-	$sock->configure(\%arg) || !$sock->blocking || return;
+	$sock->configure(\%arg) || $SOCKS_ERROR == SOCKS_WANT_WRITE || return;
 	$sock;
 }
 
